import base64
import logging
import os

import requests

from . import kafka_yaml
from .utils import memoize_args, profile

filename = os.path.basename(__file__)[:-3]

logger = logging.getLogger(filename)


def encode_token(username, password):
    token = base64.b64encode(f"{username}:{password}".encode())
    return token.decode()


def get_creds(cluster_alias):
    for region in kafka_yaml["regions"]:
        if cluster_alias.startswith(region["name"]):
            return region


@profile
@memoize_args
def get_identity_v2_token(cluster_alias):
    logger.debug(f"get_identity_v2_token(cluster_alias: {cluster_alias})")
    payload = "grant_type=client_credentials&scope=openid%20profile"
    region = get_creds(cluster_alias)
    headers = {
        "Content-Type": "application/x-www-form-urlencoded",
        "Authorization": f"Basic {encode_token(region['client'], region['secret'])}",
        "Cookie": "ha_backend_openam=s0.0.1935-3",
    }
    response = requests.request("POST", region["url"], headers=headers, data=payload)
    response.raise_for_status()
    if response.status_code == 200:
        response_json = response.json()
        logger.debug(f"response_json: {response_json}")
        access_token = response_json["access_token"]
        logger.debug(f"get_identity_v2_token()->({access_token})")
        return access_token
