#!/usr/bin/env python3

"""Main module."""

import logging
import os
import time

from .kafkacmp import process_kobjs
from .utils import PROF_DATA, load_config, set_log_level, write_log

filename = os.path.basename(__file__)[:-3]

logger = logging.getLogger(filename)

### main ###


def main():
    start = time.time()
    try:
        set_log_level()
        config_yaml = load_config("APP_CONFIG", f"config/{filename}.yml")
        # process all kafka objects types in config yaml
        results = process_kobjs(config_yaml)
        return write_log(results, f"logs/{filename}")
    except Exception as e:
        if logger.isEnabledFor(logging.DEBUG):
            logger.exception(e)
        else:
            logger.error(e)
    finally:
        logger.debug(PROF_DATA)
        logger.debug("execution time: {}".format(time.time() - start))


if __name__ == "__main__":
    main()
